Crate generalized_paillier

Crate generalized_paillier 

Paillier encryption and Damgard-Jurik encryption

The code is generic over the prime size and expansion factor S (for Damgard-Jurik)

By default, it uses standard library and rayon for parallelization.

For no_std support, build as

cargo build --no-default-features

and for wasm-32, build as

cargo build --no-default-features --target wasm32-unknown-unknown

Modules

damgard_jurik
Generalized Paillier encryption or Damgard-Jurik encryption as described in section 3.2 of the paper A Generalization of Paillier’s Public-Key System with Applications to Electronic Voting
error
paillier_original
Paillier encryption as described in Scheme 1 of the Public-Key Cryptosystems Based on Composite Degree Residuosity Classes
util

Macros

join